Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(525)

Unified Diff: net/tools/cert_verify_tool/verify_using_path_builder.h

Issue 2130453003: cert_verify_tool: Verify using the new pathbuilder too. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@cert-parsing-path-building
Patch Set: changes for comment #3 Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/tools/cert_verify_tool/verify_using_path_builder.h
diff --git a/net/tools/cert_verify_tool/verify_using_cert_verify_proc.h b/net/tools/cert_verify_tool/verify_using_path_builder.h
similarity index 64%
copy from net/tools/cert_verify_tool/verify_using_cert_verify_proc.h
copy to net/tools/cert_verify_tool/verify_using_path_builder.h
index b31d0e1175dd8edcbb359b36e23ad80dad9b5da5..56980a98d0ac9942c2fa339e7650f9371ae5e581 100644
--- a/net/tools/cert_verify_tool/verify_using_cert_verify_proc.h
+++ b/net/tools/cert_verify_tool/verify_using_path_builder.h
@@ -2,27 +2,28 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef NET_TOOLS_CERT_VERIFY_TOOL_VERIFY_USING_CERT_VERIFY_PROC_H_
-#define NET_TOOLS_CERT_VERIFY_TOOL_VERIFY_USING_CERT_VERIFY_PROC_H_
+#ifndef NET_TOOLS_CERT_VERIFY_TOOL_VERIFY_USING_PATH_BUILDER_H_
+#define NET_TOOLS_CERT_VERIFY_TOOL_VERIFY_USING_PATH_BUILDER_H_
#include <string>
#include <vector>
namespace base {
class FilePath;
+class Time;
}
struct CertInput;
// Verifies |target_der_cert| using CertVerifyProc. Returns true if the
// certificate verified successfully, false if it failed to verify or there was
// some other error.
// Informational messages will be printed to stdout/stderr as appropriate.
-bool VerifyUsingCertVerifyProc(
+bool VerifyUsingPathBuilder(
const CertInput& target_der_cert,
- const std::string& hostname,
const std::vector<CertInput>& intermediate_der_certs,
const std::vector<CertInput>& root_der_certs,
+ const base::Time at_time,
const base::FilePath& dump_prefix_path);
-#endif // NET_TOOLS_CERT_VERIFY_TOOL_VERIFY_USING_CERT_VERIFY_PROC_H_
+#endif // NET_TOOLS_CERT_VERIFY_TOOL_VERIFY_USING_PATH_BUILDER_H_
« no previous file with comments | « net/tools/cert_verify_tool/cert_verify_tool.cc ('k') | net/tools/cert_verify_tool/verify_using_path_builder.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -2,27 +2,28 @@
}
struct CertInput;
-// Verifies |target_der_cert| using CertVerifyProc. Returns true if the
+// Verifies |target_der_cert| using CertPathBuilder. Returns true if the
// certificate verified successfully, false if it failed to verify or there was
// some other error.
This is Rietveld 408576698